/// <reference types="node" />
import { OpfCreator } from "./OpfCreator";
import { OpfGuideCollection } from "./OpfGuideCollection";
import { OpfManifest } from "./OpfManifest";
import { OpfSpine } from "./OpfSpine";
import { OpfDate } from "./OpfDate";
import { OpfIdentifier } from "./OpfIdentifier";
import { OpfPublisher } from "./OpfPublisher";
import { OpfSeries } from "./OpfSeries";
/**
* Defines the top-level class for representing an OPF file.
*/
export declare class Opf {
    contributors: OpfCreator[];
    coverImage: string;
    creators: OpfCreator[];
    dates: OpfDate[];
    description: string | undefined;
    guides: OpfGuideCollection;
    identifiers: OpfIdentifier[];
    language: string;
    manifests: OpfManifest[];
    publishers: OpfPublisher[];
    rights: string | undefined;
    series: OpfSeries | undefined;
    spines: OpfSpine[];
    subjects: string[];
    title: string;
    toc: string;
    readonly uniqueIdentifier: OpfIdentifier;
    toBuffer(): Buffer;
    /**
     * Validates the correctness of the OPF settings.
     *
     * @returns {string[]} A list of validation errors or empty list if
     *  there are no validation errors.
     */
    validate(): string[];
    private writeMetadata(xml);
    private writeGuide(xml);
    private writeManifest(xml);
    private writeSpine(xml);
}
